==> fastsms_0.5-3.tar.gz: fastsms-0.5/src/kb_qwerty.h <==
/****************************************************************************
**
** Copyright (C) 2010  Aimone Davide realsportcars@hotmail.com
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#ifndef KB_QWERTY_H
#define KB_QWERTY_H

#include <QWidget>
#include "keyboard.h"

namespace Ui {
    class kb_Qwerty;
}

class kb_Qwerty : public Keyboard
{
    Q_OBJECT

public:
    explicit kb_Qwerty(QWidget *parent = 0, bool bStandalone = false);
    ~kb_Qwerty();


private:
    Ui::kb_Qwerty *ui;
    int m_nActiveModifiers;
    void setButtonsLabel();

public slots:
    void directInputClicked();
           // void settingsChanged(int);

private slots:
    void maiuscClicked(/*int nForceCheck = 0*/);
    void symClicked();
    void newLineClicked();
    void spaceClicked();
    void deleteClicked();
    void accentClicked();

};

#endif // KB_QWERTY_H

==> fastsms_0.5-8.tar.gz: fastsms-0.5/src/kb_qwerty.h <==
/****************************************************************************
**
** Copyright (C) 2010  Aimone Davide realsportcars@hotmail.com
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#ifndef KB_QWERTY_H
#define KB_QWERTY_H

#include <QWidget>
#include "keyboard.h"

namespace Ui {
    class kb_Qwerty;
}

class kb_Qwerty : public Keyboard
{
    Q_OBJECT

public:
    explicit kb_Qwerty(QWidget *parent = 0/*, bool bStandalone = false, bool bSymbol = false*/);
    ~kb_Qwerty();
    void setScope(bool bStandalone, bool bOnlySymbol = false);
    void loadLayout(Core::QwertyLayout layout=Core::noneLayout);


private:
    Ui::kb_Qwerty *ui;
//    int m_nActiveModifiers;
    //void setButtonsLabel();

public slots:
    void directInputClicked();
           // void settingsChanged(int);

private slots:
    //void maiuscClicked(/*int nForceCheck = 0*/);
    void symClicked();
    void newLineClicked();
    void spaceClicked();
    void deleteClicked();
    void accentClicked();

};

#endif // KB_QWERTY_H
